;***********************************************************************;
;												<<< REGAL.LSP >>>																;
;***********************************************************************;
;
;Autor: K.Habenicht
;Datum der Erstellung: 19.1.1995
;Datum der letzten Vernderung:
;
;Funktion: 3D-Variantenkonstruktion eines Bcherregals
;Dialogbox: REGAL.DCL
;**************************** Variablen ********************************;
;P1 - P8		Punkte
;stark			Brettstrke
;anzahl			Anzahl der Regalbretter
;breite			Regalbreite
;hoehe			Regalhhe
;tiefe			Regaltiefe
;brbreit		Brettbreite
;brtief			Brettiefe
;vsvorn			vordere Verschiebung der Regalbretter
;vshint			hintere Verschiebung der Regalbretter
;abstreg		Abstand der Regalbretter
;**************************** Programm *********************************;

;Fehlerroutine
(defun *error* (msg)
(princ msg)
(setvar "CMDECHO" cmd)
(setvar "BLIPMODE" blip)
(setvar "OSMODE" osm)
(setvar "CLAYER" lay)
(princ)
)

;Hauptprogramm

(defun C:REGAL(/ P1 P2 P3 P4 P5 P6 P7 P8 stark breite 
								 hoehe tiefe anzahl brbreit brtief
								 vsvorn vshint abstreg DCL_ID)
;Sichern der Systemvariablen
	(setq cmd (getvar "CMDECHO"))
	(setq blip (getvar "BLIPMODE"))
	(setq osm (getvar "OSMODE"))
	(setq lay (getvar "CLAYER"))
	(setvar "BLIPMODE" 0)
	(setvar "OSMODE" 0)
;Eingabeteil
;Vordefinieren der Variablen
	(setq breite 60.0
		  	hoehe 200.0
			  tiefe 40.0
				stark 2.0
				anzahl 5
				vsvorn 1.0			;Versatz der Regalbretter vorne
				vshint 1.0			;Versatz der Regalbretter hinten
	)
;Layer Moebel einschalten
	(setq istda (ssget "X" '((8 . "MOEBEL"))))
	(if (not istda) (command "LAYER" "MACH" "MOEBEL" "FA" "gelb" "" "")
	(command "LAYER" "SETZ" "MOEBEL" ""))

;Eingabeteil
(setq P1 (getpoint "\nEinfgepunkt (links vorne): "))

;Dialogbox laden
	(if (< (setq DCL_ID (load_dialog "REGAL.DCL")) 0) 
		(progn
			(alert "DCL-Datei nicht gefunden!")
			(exit)
		)
	)
	(if (not (new_dialog "regal" DCL_ID)) (exit))
;Vorgabewerte in Dialogbox schreiben
	(set_tile "breite" (rtos breite 2 2))
	(set_tile "hoehe" (rtos hoehe 2 2))
	(set_tile "tiefe" (rtos tiefe 2 2))	
	(set_tile "stark" (rtos stark 2 2))	
	(set_tile "anzahl" (rtos anzahl 2 2))	

;Eingabe ber Dialogbox definieren
	(action_tile "breite" "(setq breite (setz_breite (distof $VALUE)))")
	(action_tile "hoehe" "(setq hoehe (setz_hoehe (distof $VALUE)))")
	(action_tile "tiefe" "(setq tiefe (setz_tiefe (distof $VALUE)))")
	(action_tile "stark" "(setq stark (setz_stark (distof $VALUE)))")
	(action_tile "anzahl" "(setq anzahl (setz_anzahl (atoi $VALUE)))")
	(action_tile "cancel" "(endprog)")
	(start_dialog)

;Rechenteil
	(setvar "CMDECHO" 0)
	(setq brbreit (- breite stark stark)
				brtief (- tiefe vsvorn vshint)
				abstreg (/ (- hoehe stark)(1- anzahl))
	)
;Punkte des linken Seitenbretts
(setq P2 (list (+ (car P1) stark) (cadr P1) (caddr P1))
			P3 (list (car P2) (+ (cadr P2) tiefe) (caddr P1))
			P4 (list (car P1) (cadr P3)	(caddr P1))
			P5 (list (car P1)(cadr P1) (+ (caddr P1) hoehe))
			P6 (list (car P2)(cadr P2) (caddr P5))
			P7 (list (car P3)(cadr P3) (caddr P5))
			P8 (list (car P4)(cadr P4) (caddr P5))
)
;Zeichnen der Seitenbretter
(command "3DNETZ" "6" "3" P6 P2 P2 P5 P1 P1 P8 P4 P1
													P7 P3 P2 P7 P7 P6 P8 P8 P5
)
(command "KOPIEREN" "l" "" (list (- breite stark) 0 0) "")
;Punkte eines Regalbretts
(setq P1 (list (car P2) (+ (cadr P2) vsvorn) (caddr P2))
			P2 (list (+ brbreit (car P1))(cadr P1)(caddr P1))
			P3 (list (car P2)(+ (cadr P2) brtief)(caddr P1))
			P4 (list (car P1)(cadr P3)(caddr P1))
			P5 (list (car P1)(cadr P1)(+ (caddr P1) stark))
			P6 (list (car P2)(cadr P2)(caddr P5))
			P7 (list (car P3)(cadr P3)(caddr P5))
			P8 (list (car P4)(cadr P4)(caddr P5))
)
;Zeichnen eines Regalbretts
(command "3DNETZ" "5" "2" P2 P1 P3 P4 P7 P8 P6 P5 P2 P1)
(setq i 1)
(repeat (1- anzahl)
	(command "KOPIEREN" "l" "" (list 0 0 abstreg) "")
)
;Systemvariablen zurckschreiben
	(unload_dialog DCL_ID)
	(setvar "CLAYER" lay)
	(setvar "OSMODE" osm)
	(setvar "BLIPMODE" blip)
	(setvar "CMDECHO" cmd)
(princ)
) ;Ende Hauptprogramm

;Unterprogramme fr Dialogbox
(defun setz_breite (neubr)
	(set_tile "breite" (rtos neubr 2 2))
neubr
)

(defun setz_hoehe (neuh)
	(set_tile "hoehe" (rtos neuh 2 2))
neuh
)

(defun setz_tiefe (neutief)
	(set_tile "tiefe" (rtos neutief 2 2))
neutief
)

(defun setz_stark (neustark)
	(set_tile "stark" (rtos neustark 2 2))
neustark
)

(defun setz_anzahl (neuanz)
	(set_tile "anzahl" (itoa neuanz))
neuanz
)

(defun endprog()
	(done_dialog)
	(princ "Programm abgebrochen")
	(exit)
)
